:orphan:

.. include:: _contributors.rst
.. currentmodule:: treeple

.. _v0_4:

Version 0.4
===========

This version patches some issues with the ``FeatureImportance*`` classes and also adds a feature to the
`MultiViewDecisionTreeClassifier` class that allows one to scale the number of split candidates sampled per feature-set
equally.

Changelog
---------

- |API| ``FeatureImportanceForest*`` now has a hyperparameter to control the number of permutations is done per forest ``permute_per_forest_fraction``, by `Adam Li`_ (:pr:`145`)
- |Enhancement| Add dataset generators for regression and classification and hypothesis testing, by `Adam Li`_ (:pr:`169`)
- |Fix| Fixes a bug where ``FeatureImportanceForest*`` was unable to be run when calling ``statistic`` with ``covariate_index`` defined for MI, AUC metrics, by `Adam Li`_ (:pr:`164`)
- |Enhancement| Add :func:`treeple.experimental.conditional_resample`, which allows conditional resampling of rows based on nearest-neighbors defined via a feature set, by `Adam Li`_ (:pr:`170`)
- |Enhancement| Multi-view trees now are able to scale the sampling of split candidates at the same rate per feature-set now, which means 'sqrt' would sample split candidates equal to the square root of each feature-set size, by `Adam Li`_ (:pr:`152`)
- |FIX| Fixes bug in :class:`treeple.tree.MultiViewDecisionTreeClassifier` where the max_features argument applied over
    more than two views with ``apply_max_features_per_set`` set to ``True`` results in an incorrect and oversampled
    number of max_features in the views after the first two, by `Adam Li`_ (:pr:`172`)

Code and Documentation Contributors
-----------------------------------

Thanks to everyone who has contributed to the maintenance and improvement of
the project since version inception, including:

* `Adam Li`_

